@@ -9,7 +9,7 @@ if not environ.get('DISPLAY'):
     mpl.use('Agg')
 import matplotlib.pyplot as plt  # pylint: disable=wrong-import-order
 
-from mlx.traceability import report_warning
+from mlx.traceability_exception import report_warning
 from mlx.traceable_base_directive import TraceableBaseDirective
 from mlx.traceable_base_node import TraceableBaseNode
 from mlx.traceable_item import TraceableItem
@@ -29,11 +29,14 @@ def pct_wrapper(sizes):
 
 class ItemPieChart(TraceableBaseNode):
     '''Pie chart on documentation items'''
-    collection = None
-    relationships = []
-    priorities = {}  # default priority order is 'uncovered', 'covered', 'executed', 'pass', 'fail', 'error'
-    attribute_id = ''
-    linked_attributes = {}  # source_id (str): attr_value (str)
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.collection = None
+        self.relationships = []
+        self.priorities = {}  # default priority order is 'uncovered', 'covered', 'executed', 'pass', 'fail', 'error'
+        self.attribute_id = ''
+        self.linked_attributes = {}  # source_id (str): attr_value (str)
 
     def perform_replacement(self, app, collection):
         """
@@ -52,20 +55,19 @@ class ItemPieChart(TraceableBaseNode):
         self._set_priorities()
         self._set_attribute_id()
 
-        for source_id in self.collection.get_items(''):
+        for source_id in self.collection.get_items(self['id_set'][0]):
             source_item = self.collection.get_item(source_id)
             # placeholders don't end up in any item-piechart (less duplicate warnings for missing items)
             if source_item.is_placeholder():
                 continue
-            if re.match(self['id_set'][0], source_id):
-                self.linked_attributes[source_id] = self['label_set'][0].lower()  # default is "uncovered"
-                self.loop_relationships(source_id, source_item, self['id_set'][1], self._match_covered)
+            self.linked_attributes[source_id] = self['label_set'][0].lower()  # default is "uncovered"
+            self.loop_relationships(source_id, source_item, self['id_set'][1], self._match_covered)
 
         chart_labels, statistics = self._prepare_labels_and_values(list(self.priorities),
                                                                    list(self.linked_attributes.values()))
         p_node = nodes.paragraph()
         p_node += nodes.Text(statistics)
-        p_node += self.build_pie_chart(chart_labels, env)
+        top_node += self.build_pie_chart(chart_labels, env)
         top_node += p_node
         self.replace_self(top_node)
 
@@ -207,9 +209,7 @@ class ItemPieChart(TraceableBaseNode):
         """
         labels = list(chart_labels)
         sizes = list(chart_labels.values())
-        explode = [0] * len(labels)
-        uncoverd_index = labels.index(self['label_set'][0])
-        explode[uncoverd_index] = 0.05  # slightly detaches slice of first state, default is "uncovered"
+        explode = self._get_explode_values(labels, self['label_set'])
 
         fig, axes = plt.subplots()
         axes.pie(sizes, explode=explode, labels=labels, autopct=pct_wrapper(sizes), startangle=90)
@@ -231,6 +231,26 @@ class ItemPieChart(TraceableBaseNode):
         image_node['candidates'] = '*'  # look at uri value for source path, relative to the srcdir folder
         return image_node
 
+    @staticmethod
+    def _get_explode_values(labels, label_set):
+        """ Gets a list of values indicating how far to detach each slice of the pie chart
+
+        Only the first configured state gets detached slightly; default is "uncovered"
+
+        Args:
+            labels (list): Slice labels (str)
+            label_set (list): All labels as configured by the label_set option
+
+        Returns:
+            list: List of numbers for each slice indicating how far to detach it
+        """
+        explode = [0] * len(labels)
+        uncovered_label = label_set[0]
+        if uncovered_label in labels:
+            uncovered_index = labels.index(uncovered_label)
+            explode[uncovered_index] = 0.05
+        return explode
+
 
 class ItemPieChartDirective(TraceableBaseDirective):
     """
