@@ -18,6 +18,7 @@ from sphinx.errors import NoUri
 from docutils import nodes
 from docutils.parsers.rst import directives
 
+from mlx.__traceability_version__ import version
 from mlx.traceable_attribute import TraceableAttribute
 from mlx.traceable_base_node import TraceableBaseNode
 from mlx.traceable_item import TraceableItem
@@ -445,7 +446,7 @@ def _parse_description(description, attr_values, merge_request_id, regex):
     query_results = {}
     for line in description.split('\n'):
         # catch the content of checkbox and the item ID after the checkbox
-        cli_match = match(r"\s*[\*\-]\s+\[(?P<checkbox>[\sx])\]\s+(?P<target_id>{})".format(regex), line)
+        cli_match = match(r"\s*[\*\-]\s+\[(?P<checkbox>[\sx])\]\s+[*_`~]*(?P<target_id>{})".format(regex), line)
         if cli_match:
             if cli_match.group('checkbox') == 'x':
                 item_info = ItemInfo(attr_values[0], merge_request_id)
@@ -484,6 +485,8 @@ def setup(app):
             'attendees': '^([A-Z]{3}[, ]*)+$',
             'assignee': '^.*$',
             'effort': r'^([\d\.]+(mo|[wdhm]) ?)+$',
+            'non_functional': '^.{0}$',
+            'functional': '^.{0}$',
         },
         'env',
     )
@@ -500,6 +503,8 @@ def setup(app):
             'attendees': 'Attendees',
             'assignee': 'Assignee',
             'effort': 'Effort estimation',
+            'non_functional': 'Non-functional',
+            'functional': 'Functional',
         },
         'env',
     )
@@ -606,10 +611,12 @@ def setup(app):
     app.add_directive('attribute-link', AttributeLinkDirective)
     app.add_directive('attribute-sort', AttributeSortDirective)
 
-    app.connect('doctree-resolved', process_item_nodes)
-    app.connect('env-check-consistency', perform_consistency_check)
     app.connect('builder-inited', initialize_environment)
+    app.connect('env-check-consistency', perform_consistency_check)
+    app.connect('doctree-resolved', process_item_nodes)
 
     app.add_role('item', XRefRole(nodeclass=PendingItemXref,
                                   innernodeclass=nodes.emphasis,
                                   warn_dangling=True))
+
+    return {'version': version}
