@@ -51,6 +51,25 @@ class TraceableBaseDirective(Directive, ABC):
         for attr in set(TraceableItem.defined_attributes) & set(self.options) - self.conflicting_options:
             node['filter-attributes'][attr] = self.options[attr]
 
+    def add_attributes(self, node, option, default, description='attribute'):
+        """ Adds all valid attribute keys in the option's value to the node
+
+        A warning is reported for every unknown attribute and in case of comma- instead of space-separation.
+        If the option is not used or its value is empty, the ``default`` value is used.
+
+        Args:
+            node (TraceableBaseNode): Node object for which to add the attributes to, using ``option`` as key.
+            option (str): Name of the option to look for
+            default (list): Default attributes to use
+            description (str): Describes what kind of attribute it is, to use in warning message
+        """
+        if option in self.options and self.options[option]:
+            self._warn_if_comma_separated(option, node['document'])
+            node[option] = self.options[option].split()
+        else:
+            node[option] = default
+        self.remove_unknown_attributes(node[option], description, node['document'])
+
     def remove_unknown_attributes(self, attributes, description, docname):
         """ Removes any unknown attributes from the given list while reporting a warning.
 
@@ -60,10 +79,28 @@ class TraceableBaseDirective(Directive, ABC):
             docname (str): Document name.
         """
         for attr in set(attributes) - set(TraceableItem.defined_attributes):
-            report_warning('Traceability: unknown %s for item-attributes-matrix: %s' % (description, attr),
+            report_warning('Traceability: unknown %s for item-(attributes-)matrix: %s' % (description, attr),
                            docname, self.lineno)
             attributes.remove(attr)
 
+    def add_attributes_and_relations(self, node, option, defined_relations):
+        """ Adds all valid attribute keys in the option's value to the node along with valid relationships
+
+        Args:
+            node (TraceableBaseNode): Node object for which to add valid values to, using ``option`` as key.
+            option (str): Name of the option to look for
+            defined_relations (dict): All defined relationships
+        """
+        node[option] = []
+        if option in self.options:
+            values = self.options[option].split()
+            self._warn_if_comma_separated(option, node['document'])
+            for value in values:
+                if value in defined_relations or value in TraceableItem.defined_attributes:
+                    node[option].append(value)
+            leftover_values = set(values).difference(node[option])
+            self.remove_unknown_attributes(leftover_values, 'attribute/relationship', node['document'])
+
     def check_relationships(self, relationships, env):
         """  Checks if given relationships are in configuration.
 
